@@ -357,14 +357,14 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
 def deploy_core(logger,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
     if deploy_biz_services(logger,app_name,stage,app_domain,brand,env,app_suffix,aws_profile) :
         if deploy_app_services(logger,app_domain,brand,env,aws_profile) :
-            if deploy_service_module(logger,"ac-core",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                if deploy_service_module(logger,"ac-datastore",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                    if deploy_service_module(logger,"ac-allowlist",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                        if deploy_service_module(logger,"ac-automation",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                            if deploy_service_module(logger,"ac-macro-security",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                                if deploy_service_module(logger,"ac-migrations",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                                    if deploy_service_module(logger,"ac-proxy",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
-                                        if deploy_service_module(logger,"ac-utils",False,app_name,stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag):
+            if deploy_service_module(logger,"ac-core",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                if deploy_service_module(logger,"ac-datastore",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                    if deploy_service_module(logger,"ac-allowlist",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                        if deploy_service_module(logger,"ac-automation",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                            if deploy_service_module(logger,"ac-macro-security",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                                if deploy_service_module(logger,"ac-migrations",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                                    if deploy_service_module(logger,"ac-proxy",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
+                                        if deploy_service_module(logger,"ac-utils",False,app_name,stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag):
                                             if deploy_module_services(logger,app_name,stage,app_domain,brand,env,app_suffix,aws_profile):
                                                 print('Core services deployed successfully.')
 
